============
Installation
============

Install scopus with:

.. code-block:: console

    $ pip install scopus

or directly from the GitHub repository (may be unstable):

.. code-block:: console

    $ pip install git+git://github.com/scopus-api/scopus

Using Scopus is not free. You need to have a license or institutional access to use it.  Additionally, you need a key.  Go to http://dev.elsevier.com/myapikey.html to register and get a key.  On first usage, `scopus` asks you to enter to key which will be stored in `~/.scopus/my_scopus.py`.
